@@ -70,7 +70,7 @@ class CommitsByRepository(Commits):
 class CommitsByTicket(Commits):
     master_key = 'ticket'
     column_names = 'repository summary user url'
-    display_mode = "summary"
+    display_mode_main = "summary"
     # stay_in_grid = True
 
     @classmethod
