@@ -209,6 +209,9 @@ class Commit(Created, Authored):
         except Commit.DoesNotExist:
             id = None
 
+        with timezone.override('UTC'):
+            created = timezone.make_aware(timezone.datetime.strptime(d['commit']['committer']['date'], "%Y-%m-%dT%H:%M:%SZ"))
+
         params = dict(
             id=id,
             repository=repo,
@@ -218,8 +221,7 @@ class Commit(Created, Authored):
             commiter_name=d['commit']['committer']['name'],
             sha=d['sha'],
             url=d['html_url'],
-            created=timezone.utc.localize(
-                timezone.datetime.strptime(d['commit']['committer']['date'], "%Y-%m-%dT%H:%M:%SZ")),
+            created=created,
             description=d['commit']['message'],
             summary=d['commit']['message'].split('\n', 1)[0][0:100],
             comment="",
