@@ -420,12 +420,10 @@ class SpawnTicket(dd.Action):
     # show_in_bbar = False
     # goto_new = True
     params_layout = """
-    link_type
     ticket_summary
     """
 
     parameters = dict(
-        link_type=LinkTypes.field(default='requires'),
         ticket_summary=models.CharField(
             pgettext("Ticket", "Summary"), max_length=200,
             blank=False)
@@ -443,13 +441,21 @@ class SpawnTicket(dd.Action):
         child = rt.models.tickets.Ticket(
             user=ar.get_user(),
             summary=pv.ticket_summary,
-            site=parent.site)
+            site=parent.site,
+            parent=parent)
         child.full_clean()
         child.save_new_instance(ar)
-        link = rt.models.tickets.Link(
-            parent=parent, child=child, type=pv.link_type)
-        link.full_clean()
-        link.save(force_insert=True)
+        # parent.comments.create(body="@" + ar.get_user().username + " " + _("created new child ticket") + " " + "#" + str(child.id))
+        comment = rt.models.comments.Comment(
+            body="@" + ar.get_user().username + " " + _("created new child ticket") + " " + "#" + str(child.id)
+        )
+        comment.owner = parent
+        comment.full_clean()
+        comment.save_new_instance(ar)
+        # link = rt.models.tickets.Link(
+        #     parent=parent, child=child, type=pv.link_type)
+        # link.full_clean()
+        # link.save(force_insert=True)
         ar.goto_instance(child)
         ar.success()
 
