@@ -72,7 +72,7 @@ VoucherTypes.add_item_lazy(InvoicesByJournal)
 
 class ItemsByInvoice(ItemsByVoucher):
     model = 'vat.InvoiceItem'
-    display_mode = 'grid'
+    display_mode_main = 'grid'
     column_names = "account title vat_class total_incl total_base total_vat"
 
 
